==> plugin-api-1.3-sources.jar: com/xebialabs/deployit/hostsession/LenientTemplateResolvingHostFileInputTransformer.java <==
/*
 * Copyright (c) 2008-2010 XebiaLabs B.V. All rights reserved.
 *
 * Your use of XebiaLabs Software and Documentation is subject to the Personal
 * License Agreement.
 *
 * http://www.xebialabs.com/deployit-personal-edition-license-agreement
 *
 * You are granted a personal license (i) to use the Software for your own
 * personal purposes which may be used in a production environment and/or (ii)
 * to use the Documentation to develop your own plugins to the Software.
 * "Documentation" means the how to's and instructions (instruction videos)
 * provided with the Software and/or available on the XebiaLabs website or other
 * websites as well as the provided API documentation, tutorial and access to
 * the source code of the XebiaLabs plugins. You agree not to (i) lease, rent
 * or sublicense the Software or Documentation to any third party, or otherwise
 * use it except as permitted in this agreement; (ii) reverse engineer,
 * decompile, disassemble, or otherwise attempt to determine source code or
 * protocols from the Software, and/or to (iii) copy the Software or
 * Documentation (which includes the source code of the XebiaLabs plugins). You
 * shall not create or attempt to create any derivative works from the Software
 * except and only to the extent permitted by law. You will preserve XebiaLabs'
 * copyright and legal notices on the Software and Documentation. XebiaLabs
 * retains all rights not expressly granted to You in the Personal License
 * Agreement.
 */

package com.xebialabs.deployit.hostsession;

import java.io.ByteArrayInputStream;
import java.io.InputStream;
import java.util.Map;

import com.xebialabs.deployit.util.TemplateResolver;

public class LenientTemplateResolvingHostFileInputTransformer implements	HostFileInputStreamTransformer {
	
	private TemplateResolver resolver;
	
	public LenientTemplateResolvingHostFileInputTransformer(Map<String, String> properties) {
		this.resolver = new TemplateResolver(properties);
	}

	public InputStream transform(HostFile input) {
		String inputFileAsString = HostFileUtils.getHostFileAsString(input);
		
		String resolvedFileAsString = resolver.resolveLenient(inputFileAsString);
		return new ByteArrayInputStream(resolvedFileAsString.getBytes());
	}

}

==> plugin-api-1.4-sources.jar: com/xebialabs/deployit/hostsession/LenientTemplateResolvingHostFileInputTransformer.java <==
/*
 * Copyright (c) 2008-2010 XebiaLabs B.V. All rights reserved.
 *
 * Your use of XebiaLabs Software and Documentation is subject to the Personal
 * License Agreement.
 *
 * http://www.xebialabs.com/deployit-personal-edition-license-agreement
 *
 * You are granted a personal license (i) to use the Software for your own
 * personal purposes which may be used in a production environment and/or (ii)
 * to use the Documentation to develop your own plugins to the Software.
 * "Documentation" means the how to's and instructions (instruction videos)
 * provided with the Software and/or available on the XebiaLabs website or other
 * websites as well as the provided API documentation, tutorial and access to
 * the source code of the XebiaLabs plugins. You agree not to (i) lease, rent
 * or sublicense the Software or Documentation to any third party, or otherwise
 * use it except as permitted in this agreement; (ii) reverse engineer,
 * decompile, disassemble, or otherwise attempt to determine source code or
 * protocols from the Software, and/or to (iii) copy the Software or
 * Documentation (which includes the source code of the XebiaLabs plugins). You
 * shall not create or attempt to create any derivative works from the Software
 * except and only to the extent permitted by law. You will preserve XebiaLabs'
 * copyright and legal notices on the Software and Documentation. XebiaLabs
 * retains all rights not expressly granted to You in the Personal License
 * Agreement.
 */

package com.xebialabs.deployit.hostsession;

import com.xebialabs.deployit.ci.artifact.mapping.PlaceholderFormat;
import com.xebialabs.deployit.util.TemplateResolver;

import java.io.ByteArrayInputStream;
import java.io.InputStream;
import java.util.Map;

/**
 * @Deprecated use  LenientTemplateResolvingArchiveHostFileInputTransformer
 *
 */
@Deprecated
public class LenientTemplateResolvingHostFileInputTransformer implements	HostFileInputStreamTransformer {
	
	private TemplateResolver resolver;

	public LenientTemplateResolvingHostFileInputTransformer(Map<String, String> properties) {
		this(properties, PlaceholderFormat.SPRING);
	}
	
	public LenientTemplateResolvingHostFileInputTransformer(Map<String, String> properties,PlaceholderFormat placeholderFormat) {
		this.resolver = new TemplateResolver(properties,placeholderFormat);
	}

	public InputStream transform(HostFile input) {
		String inputFileAsString = HostFileUtils.getHostFileAsString(input);
		
		String resolvedFileAsString = resolver.resolveLenient(inputFileAsString);
		return new ByteArrayInputStream(resolvedFileAsString.getBytes());
	}

}
